@@ -1,9 +1,10 @@
 from warnings import warn
-
 import workos
 from workos.utils.request import (
     RequestHelper,
     REQUEST_METHOD_POST,
+    REQUEST_METHOD_DELETE,
+    REQUEST_METHOD_GET,
 )
 from workos.utils.validation import MFA_MODULE, validate_settings
 from workos.resources.mfa import (
@@ -88,6 +89,57 @@ class Mfa(object):
 
         return WorkOSAuthenticationFactorSms.construct_from_response(response).to_dict()
 
+    def get_factor(
+        self,
+        authentication_factor_id=None,
+    ):
+        """
+        Returns an authorization factor from its ID.
+
+        Kwargs:
+            authentication_factor_id (str) - The ID of the factor to be obtained.
+
+        Returns: Dict containing the authentication factor information.
+        """
+
+        if authentication_factor_id is None:
+            raise ValueError("Incomplete arguments. Need to specify a factor ID")
+
+        response = self.request_helper.request(
+            "auth/factors/{authentication_factor_id}",
+            method=REQUEST_METHOD_GET,
+            token=workos.api_key,
+        )
+
+        if response["type"] == "totp":
+            return WorkOSAuthenticationFactorTotp.construct_from_response(
+                response
+            ).to_dict()
+
+        return WorkOSAuthenticationFactorSms.construct_from_response(response).to_dict()
+
+    def delete_factor(
+        self,
+        authentication_factor_id=None,
+    ):
+        """
+        Deletes an MFA authorization factor.
+
+        Kwargs:
+            authentication_factor_id (str) - The ID of the authorization factor to be deleted.
+
+        Returns: Does not provide a response.
+        """
+
+        if authentication_factor_id is None:
+            raise ValueError("Incomplete arguments. Need to specify a factor ID.")
+
+        return self.request_helper.request(
+            "auth/factors/{authentication_factor_id}",
+            method=REQUEST_METHOD_DELETE,
+            token=workos.api_key,
+        )
+
     def challenge_factor(
         self,
         authentication_factor_id=None,
