@@ -1,3 +1,5 @@
+import platform
+
 import requests
 
 import workos
@@ -9,7 +11,10 @@ from workos.exceptions import (
 )
 
 BASE_HEADERS = {
-    "User-Agent": "WorkOS Python/{}".format(workos.__version__),
+    "User-Agent": "WorkOS Python/{} Python SDK/{}".format(
+        platform.python_version(),
+        workos.__version__,
+    ),
 }
 
 RESPONSE_TYPE_CODE = "code"
@@ -50,7 +55,7 @@ class RequestHelper(object):
 
         Kwargs:
             method (str): One of the supported methods as defined by the REQUEST_METHOD_X constants
-            params (dict): Query params to be added to the request
+            params (dict): Query params or body payload to be added to the request
             token (str): Bearer token
 
         Returns:
